;;; arabic.el  --- support for Arabic script -*- coding: iso-2022-7bit; -*- 

;;  Copyright (C) 2005  Free Software Foundation, Inc.

;; Author: Thamer Mahmoud <thamer@newkuawit.org>
;; Keywords: multilingual, Arabic, i18n

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; Support for Arabic script. Includes Arabic iso-8859-6
;; decoding/encoding, Persian UTF-8, and Windows-1256 language
;; environments. Note that right-to-left writing and contextual glyph
;; shaping is not yet supported.

;;; Code:

(make-coding-system
 'arabic-iso-8bit 2 ?6
 "ISO 2022 based 8-bit encoding for Arabic (MIME:ISO-8859-6)."
 '(ascii arabic-iso8859-6 nil nil
   nil nil nil nil nil nil nil nil t nil nil t)
 '((safe-charsets ascii arabic-iso8859-6)
   (mime-charset . iso-8859-6)))

(define-coding-system-alias 'iso-8859-6 'arabic-iso-8bit)

(set-language-info-alist
 "Arabic-ISO" `((charset . (arabic-iso8859-6))
		(coding-priority arabic-iso-8bit)
		(coding-system arabic-iso-8bit)
		(nonascii-translation . arabic-iso8859-6)
		(input-method . "arabic")
		(unibyte-display . arabic-iso-8bit)
		(sample-text . ",GGdSdGe(B ,GYdjce(B")
		(documentation . "Support for Arabic
ISO-8859-6. Right-to-left writing and contextual shaping is not yet
supported."))  '("Arabic"))

(set-language-info-alist
 "Persian" '((charset mule-unicode-0100-24ff)
	     (coding-system utf-8)
	     (coding-priority utf-8)
	     (input-method . "persian")
	     (sample-text . "$,1.!-g-q-s/L(B")
	     (documentation . "Support for Persian ISIRI 2901 using
UTF-8. Right-to-left writing and contextual shaping is not yet
supported."))  '("Arabic"))

(set-language-info-alist
 "Windows-1256" '((coding-priority windows-1256)
		  (coding-system windows-1256)
		  (input-method . "arabic")
		  (features code-pages)
		  (documentation . "Support for Windows-1256 Arabic
encoding.  Right-to-left writing and contextual shaping is not yet
supported."))  '("Arabic"))

 (provide 'arabic)

;;; arabic.el ends here
